@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/env python2
 # -*- coding: iso-8859-1 -*-
 
 # Documentation is intended to be processed by Epydoc.
@@ -82,9 +82,9 @@ The Munkres algorithm runs in O(*n*\ ^3) time, rather than O(*n*!). This
 package provides an implementation of that algorithm.
 
 This version is based on
-http://www.public.iastate.edu/~ddoty/HungarianAlgorithm.html.
+http://csclab.murraystate.edu/~bob.pilgrim/445/munkres.html
 
-This version was written for Python by Brian Clapper from the (Ada) algorithm
+This version was written for Python by Brian Clapper from the algorithm
 at the above web site. (The ``Algorithm::Munkres`` Perl version, in CPAN, was
 clearly adapted from the same web site.)
 
@@ -272,7 +272,7 @@ __all__     = ['Munkres', 'make_cost_matrix']
 # ---------------------------------------------------------------------------
 
 # Info about the module
-__version__   = "1.0.8"
+__version__   = "1.0.9"
 __author__    = "Brian Clapper, bmc@clapper.org"
 __url__       = "http://software.clapper.org/munkres/"
 __copyright__ = "(c) 2008 Brian M. Clapper"
@@ -446,6 +446,7 @@ class Munkres:
                     self.marked[i][j] = 1
                     self.col_covered[j] = True
                     self.row_covered[i] = True
+                    break
 
         self.__clear_covers()
         return 3
@@ -460,7 +461,7 @@ class Munkres:
         count = 0
         for i in range(n):
             for j in range(n):
-                if self.marked[i][j] == 1:
+                if self.marked[i][j] == 1 and not self.col_covered[j]:
                     self.col_covered[j] = True
                     count += 1
 
@@ -710,7 +711,7 @@ def print_matrix(matrix, msg=None):
     width = 0
     for row in matrix:
         for val in row:
-            width = max(width, int(math.log10(val)) + 1)
+            width = max(width, len(str(val)))
 
     # Make the format string
     format = '%%%dd' % width
